@@ -15,7 +15,7 @@ class ServiceDesk(AtlassianRestAPI):
     def get_info(self):
         """ Get info about Service Desk app """
 
-        return self.get('rest/servicedeskapi/info', headers=self.experimental_headers)
+        return self.get("rest/servicedeskapi/info", headers=self.experimental_headers)
 
     def get_service_desks(self):
         """
@@ -24,11 +24,13 @@ class ServiceDesk(AtlassianRestAPI):
 
         :return: Service Desks
         """
-        service_desks_list = self.get('rest/servicedeskapi/servicedesk', headers=self.experimental_headers)
+        service_desks_list = self.get(
+            "rest/servicedeskapi/servicedesk", headers=self.experimental_headers
+        )
         if self.advanced_mode:
             return service_desks_list
         else:
-            return (service_desks_list or {}).get('values')
+            return (service_desks_list or {}).get("values")
 
     def get_service_desk_by_id(self, service_desk_id):
         """
@@ -38,7 +40,10 @@ class ServiceDesk(AtlassianRestAPI):
         :return: Service Desk
         """
 
-        return self.get('rest/servicedeskapi/servicedesk/{}'.format(service_desk_id), headers=self.experimental_headers)
+        return self.get(
+            "rest/servicedeskapi/servicedesk/{}".format(service_desk_id),
+            headers=self.experimental_headers,
+        )
 
     # Customers actions
     def create_customer(self, full_name, email):
@@ -49,12 +54,12 @@ class ServiceDesk(AtlassianRestAPI):
         :param email: str
         :return: New customer
         """
-        log.warning('Creating customer...')
-        data = {'fullName': full_name, 'email': email}
+        log.warning("Creating customer...")
+        data = {"fullName": full_name, "email": email}
 
-        return self.post('rest/servicedeskapi/customer',
-                         headers=self.experimental_headers,
-                         data=data)
+        return self.post(
+            "rest/servicedeskapi/customer", headers=self.experimental_headers, data=data
+        )
 
     def get_customer_request(self, issue_id_or_key):
         """
@@ -64,18 +69,28 @@ class ServiceDesk(AtlassianRestAPI):
         :return: Customer request
         """
 
-        return self.get('rest/servicedeskapi/request/{}'.format(issue_id_or_key), headers=self.experimental_headers)
+        return self.get(
+            "rest/servicedeskapi/request/{}".format(issue_id_or_key),
+            headers=self.experimental_headers,
+        )
 
     def get_my_customer_requests(self):
         """ Returning requests where you are the assignee """
-        response = self.get('rest/servicedeskapi/request', headers=self.experimental_headers)
+        response = self.get(
+            "rest/servicedeskapi/request", headers=self.experimental_headers
+        )
         if self.advanced_mode:
             return response
-        return (response or {}).get('values')
+        return (response or {}).get("values")
 
-    def create_customer_request(self, service_desk_id, request_type_id,
-                                values_dict, raise_on_behalf_of=None,
-                                request_participants=None):
+    def create_customer_request(
+        self,
+        service_desk_id,
+        request_type_id,
+        values_dict,
+        raise_on_behalf_of=None,
+        request_participants=None,
+    ):
         """
         Creating customer request
 
@@ -86,11 +101,11 @@ class ServiceDesk(AtlassianRestAPI):
         :param request_participants: list
         :return: New request
         """
-        log.warning('Creating request...')
+        log.warning("Creating request...")
         data = {
             "serviceDeskId": service_desk_id,
             "requestTypeId": request_type_id,
-            "requestFieldValues": values_dict
+            "requestFieldValues": values_dict,
         }
 
         if raise_on_behalf_of:
@@ -99,16 +114,14 @@ class ServiceDesk(AtlassianRestAPI):
         if request_participants:
             data["requestParticipants"] = request_participants
 
-        param_map = {
-            "headers": self.experimental_headers
-        }
+        param_map = {"headers": self.experimental_headers}
 
         if isinstance(values_dict, dict):
             param_map["json"] = data
         elif isinstance(values_dict, str):
             param_map["data"] = data
 
-        return self.post('rest/servicedeskapi/request', **param_map)
+        return self.post("rest/servicedeskapi/request", **param_map)
 
     def get_customer_request_status(self, issue_id_or_key):
         """
@@ -117,13 +130,15 @@ class ServiceDesk(AtlassianRestAPI):
         :param issue_id_or_key: str
         :return: Status name
         """
-        request = self.get('rest/servicedeskapi/request/{}/status'.format(issue_id_or_key),
-                           headers=self.experimental_headers)
+        request = self.get(
+            "rest/servicedeskapi/request/{}/status".format(issue_id_or_key),
+            headers=self.experimental_headers,
+        )
         if self.advanced_mode:
             return request
         if request:
-            if request.get('values', []):
-                return request.get('values', [])[0].get('status', {})
+            if request.get("values", []):
+                return request.get("values", [])[0].get("status", {})
         return {}
 
     def get_customer_transitions(self, issue_id_or_key):
@@ -133,7 +148,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param issue_id_or_key: str
         :return:
         """
-        url = 'rest/servicedeskapi/request/{}/transition'.format(issue_id_or_key)
+        url = "rest/servicedeskapi/request/{}/transition".format(issue_id_or_key)
 
         return self.get(url, headers=self.experimental_headers)
 
@@ -145,8 +160,10 @@ class ServiceDesk(AtlassianRestAPI):
         :return: all service desk request types
         """
 
-        return self.get('rest/servicedeskapi/servicedesk/{}/requesttype'.format(service_desk_id),
-                        headers=self.experimental_headers)
+        return self.get(
+            "rest/servicedeskapi/servicedesk/{}/requesttype".format(service_desk_id),
+            headers=self.experimental_headers,
+        )
 
     # Participants actions
     def get_request_participants(self, issue_id_or_key, start=0, limit=50):
@@ -158,17 +175,17 @@ class ServiceDesk(AtlassianRestAPI):
         :param limit: OPTIONAL: int
         :return: Request participants
         """
-        url = 'rest/servicedeskapi/request/{}/participant'.format(issue_id_or_key)
+        url = "rest/servicedeskapi/request/{}/participant".format(issue_id_or_key)
         params = {}
         if start is not None:
-            params['start'] = int(start)
+            params["start"] = int(start)
         if limit is not None:
-            params['limit'] = int(limit)
+            params["limit"] = int(limit)
 
         response = self.get(url, params=params, headers=self.experimental_headers)
         if self.advanced_mode:
             return response
-        return (response or {}).get('values')
+        return (response or {}).get("values")
 
     def add_request_participants(self, issue_id_or_key, users_list):
         """
@@ -179,8 +196,8 @@ class ServiceDesk(AtlassianRestAPI):
         :param users_list: list
         :return:
         """
-        url = 'rest/servicedeskapi/request/{}/participant'.format(issue_id_or_key)
-        data = {'usernames': users_list}
+        url = "rest/servicedeskapi/request/{}/participant".format(issue_id_or_key)
+        data = {"usernames": users_list}
 
         return self.post(url, data=data, headers=self.experimental_headers)
 
@@ -193,8 +210,8 @@ class ServiceDesk(AtlassianRestAPI):
         :param users_list: list
         :return:
         """
-        url = 'rest/servicedeskapi/request/{}/participant'.format(issue_id_or_key)
-        data = {'usernames': users_list}
+        url = "rest/servicedeskapi/request/{}/participant".format(issue_id_or_key)
+        data = {"usernames": users_list}
 
         return self.delete(url, data=data, headers=self.experimental_headers)
 
@@ -209,9 +226,9 @@ class ServiceDesk(AtlassianRestAPI):
         :param comment: OPTIONAL: str
         :return: None
         """
-        log.warning('Performing transition...')
-        data = {'id': transition_id, 'additionalComment': {'body': comment}}
-        url = 'rest/servicedeskapi/request/{}/transition'.format(issue_id_or_key)
+        log.warning("Performing transition...")
+        data = {"id": transition_id, "additionalComment": {"body": comment}}
+        url = "rest/servicedeskapi/request/{}/transition".format(issue_id_or_key)
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -225,9 +242,9 @@ class ServiceDesk(AtlassianRestAPI):
         :param public: OPTIONAL: bool (default is True)
         :return: New comment
         """
-        log.warning('Creating comment...')
+        log.warning("Creating comment...")
         data = {"body": body, "public": public}
-        url = 'rest/servicedeskapi/request/{}/comment'.format(issue_id_or_key)
+        url = "rest/servicedeskapi/request/{}/comment".format(issue_id_or_key)
 
         return self.post(path=url, data=data, headers=self.experimental_headers)
 
@@ -239,8 +256,10 @@ class ServiceDesk(AtlassianRestAPI):
         :return: Issue comments
         """
 
-        return self.get('rest/servicedeskapi/request/{}/comment'.format(issue_id_or_key),
-                        headers=self.experimental_headers)
+        return self.get(
+            "rest/servicedeskapi/request/{}/comment".format(issue_id_or_key),
+            headers=self.experimental_headers,
+        )
 
     def get_request_comment_by_id(self, issue_id_or_key, comment_id):
         """
@@ -251,9 +270,12 @@ class ServiceDesk(AtlassianRestAPI):
         :return: Single comment
         """
 
-        return self.get('rest/servicedeskapi/request/{}/comment/{}'.format(issue_id_or_key,
-                                                                           comment_id),
-                        headers=self.experimental_headers)
+        return self.get(
+            "rest/servicedeskapi/request/{}/comment/{}".format(
+                issue_id_or_key, comment_id
+            ),
+            headers=self.experimental_headers,
+        )
 
     # Organizations actions
     def get_organisations(self, service_desk_id=None, start=0, limit=50):
@@ -268,17 +290,23 @@ class ServiceDesk(AtlassianRestAPI):
                      Default: 50. See the Pagination section for more details.
         :return:
         """
-        url_without_sd_id = 'rest/servicedeskapi/organization'
-        url_with_sd_id = 'rest/servicedeskapi/servicedesk/{}/organization'.format(service_desk_id)
+        url_without_sd_id = "rest/servicedeskapi/organization"
+        url_with_sd_id = "rest/servicedeskapi/servicedesk/{}/organization".format(
+            service_desk_id
+        )
         params = {}
         if start is not None:
-            params['start'] = int(start)
+            params["start"] = int(start)
         if limit is not None:
-            params['limit'] = int(limit)
+            params["limit"] = int(limit)
 
         if service_desk_id is None:
-            return self.get(url_without_sd_id, headers=self.experimental_headers, params=params)
-        return self.get(url_with_sd_id, headers=self.experimental_headers, params=params)
+            return self.get(
+                url_without_sd_id, headers=self.experimental_headers, params=params
+            )
+        return self.get(
+            url_with_sd_id, headers=self.experimental_headers, params=params
+        )
 
     def get_organization(self, organization_id):
         """
@@ -287,7 +315,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param organization_id: str
         :return: Organization
         """
-        url = 'rest/servicedeskapi/organization/{}'.format(organization_id)
+        url = "rest/servicedeskapi/organization/{}".format(organization_id)
 
         return self.get(url, headers=self.experimental_headers)
 
@@ -300,12 +328,12 @@ class ServiceDesk(AtlassianRestAPI):
         :param limit: OPTIONAL: int
         :return: Users list in organization
         """
-        url = 'rest/servicedeskapi/organization/{}/user'.format(organization_id)
+        url = "rest/servicedeskapi/organization/{}/user".format(organization_id)
         params = {}
         if start is not None:
-            params['start'] = int(start)
+            params["start"] = int(start)
         if limit is not None:
-            params['limit'] = int(limit)
+            params["limit"] = int(limit)
 
         return self.get(url, headers=self.experimental_headers, params=params)
 
@@ -317,9 +345,9 @@ class ServiceDesk(AtlassianRestAPI):
         :param name: str
         :return: Organization data
         """
-        log.warning('Creating organization...')
-        url = 'rest/servicedeskapi/organization'
-        data = {'name': name}
+        log.warning("Creating organization...")
+        url = "rest/servicedeskapi/organization"
+        data = {"name": name}
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -331,9 +359,9 @@ class ServiceDesk(AtlassianRestAPI):
         :param organization_id: int
         :return:
         """
-        log.warning('Adding organization...')
-        url = 'rest/servicedeskapi/servicedesk/{}/organization'.format(service_desk_id)
-        data = {'organizationId': organization_id}
+        log.warning("Adding organization...")
+        url = "rest/servicedeskapi/servicedesk/{}/organization".format(service_desk_id)
+        data = {"organizationId": organization_id}
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -345,9 +373,9 @@ class ServiceDesk(AtlassianRestAPI):
         :param organization_id: int
         :return:
         """
-        log.warning('Removing organization...')
-        url = 'rest/servicedeskapi/servicedesk/{}/organization'.format(service_desk_id)
-        data = {'organizationId': organization_id}
+        log.warning("Removing organization...")
+        url = "rest/servicedeskapi/servicedesk/{}/organization".format(service_desk_id)
+        data = {"organizationId": organization_id}
 
         return self.delete(url, headers=self.experimental_headers, data=data)
 
@@ -358,8 +386,8 @@ class ServiceDesk(AtlassianRestAPI):
         :param organization_id:
         :return:
         """
-        log.warning('Deleting organization...')
-        url = 'rest/servicedeskapi/organization/{}'.format(organization_id)
+        log.warning("Deleting organization...")
+        url = "rest/servicedeskapi/organization/{}".format(organization_id)
 
         return self.delete(url, headers=self.experimental_headers)
 
@@ -372,9 +400,9 @@ class ServiceDesk(AtlassianRestAPI):
         :param users_list: list
         :return:
         """
-        log.warning('Adding users...')
-        url = 'rest/servicedeskapi/organization/{}/user'.format(organization_id)
-        data = {'usernames': users_list}
+        log.warning("Adding users...")
+        url = "rest/servicedeskapi/organization/{}/user".format(organization_id)
+        data = {"usernames": users_list}
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -387,15 +415,16 @@ class ServiceDesk(AtlassianRestAPI):
         :param users_list: list
         :return:
         """
-        log.warning('Removing users...')
-        url = 'rest/servicedeskapi/organization/{}/user'.format(organization_id)
-        data = {'usernames': users_list}
+        log.warning("Removing users...")
+        url = "rest/servicedeskapi/organization/{}/user".format(organization_id)
+        data = {"usernames": users_list}
 
         return self.delete(url, headers=self.experimental_headers, data=data)
 
     # Attachments actions
-    def create_attachment(self, service_desk_id, issue_id_or_key, filename,
-                          public=True, comment=None):
+    def create_attachment(
+        self, service_desk_id, issue_id_or_key, filename, public=True, comment=None
+    ):
         """
         Add attachment as a comment.
 
@@ -413,7 +442,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param comment: OPTIONAL: str (default is None)
         :return: Request info
         """
-        log.warning('Creating attachment...')
+        log.warning("Creating attachment...")
 
         # Create temporary attachment
         temp_attachment_id = self.attach_temporary_file(service_desk_id, filename)
@@ -429,16 +458,23 @@ class ServiceDesk(AtlassianRestAPI):
         :param filename: str
         :return: Temporary Attachment ID
         """
-        url = 'rest/servicedeskapi/servicedesk/{}/attachTemporaryFile'.format(service_desk_id)
+        url = "rest/servicedeskapi/servicedesk/{}/attachTemporaryFile".format(
+            service_desk_id
+        )
 
-        with open(filename, 'rb') as file:
-            result = self.post(path=url, headers=self.experimental_headers_general,
-                               files={'file': file}).get('temporaryAttachments')
-            temp_attachment_id = result[0].get('temporaryAttachmentId')
+        with open(filename, "rb") as file:
+            result = self.post(
+                path=url,
+                headers=self.experimental_headers_general,
+                files={"file": file},
+            ).get("temporaryAttachments")
+            temp_attachment_id = result[0].get("temporaryAttachmentId")
 
             return temp_attachment_id
 
-    def add_attachment(self, issue_id_or_key, temp_attachment_id, public=True, comment=None):
+    def add_attachment(
+        self, issue_id_or_key, temp_attachment_id, public=True, comment=None
+    ):
         """
         Adds temporary attachment to customer request using attach_temporary_file function
 
@@ -448,11 +484,13 @@ class ServiceDesk(AtlassianRestAPI):
         :param comment: str (default is None)
         :return:
         """
-        log.warning('Adding attachment')
-        data = {'temporaryAttachmentIds': [temp_attachment_id],
-                'public': public,
-                'additionalComment': {'body': comment}}
-        url = 'rest/servicedeskapi/request/{}/attachment'.format(issue_id_or_key)
+        log.warning("Adding attachment")
+        data = {
+            "temporaryAttachmentIds": [temp_attachment_id],
+            "public": public,
+            "additionalComment": {"body": comment},
+        }
+        url = "rest/servicedeskapi/request/{}/attachment".format(issue_id_or_key)
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -468,17 +506,17 @@ class ServiceDesk(AtlassianRestAPI):
         :param limit: OPTIONAL: int
         :return: SLA information
         """
-        url = 'rest/servicedeskapi/request/{}/sla'.format(issue_id_or_key)
+        url = "rest/servicedeskapi/request/{}/sla".format(issue_id_or_key)
         params = {}
         if start is not None:
-            params['start'] = int(start)
+            params["start"] = int(start)
         if limit is not None:
-            params['limit'] = int(limit)
+            params["limit"] = int(limit)
 
         response = self.get(url, params=params, headers=self.experimental_headers)
         if self.advanced_mode:
             return response
-        return (response or {}).get('values')
+        return (response or {}).get("values")
 
     def get_sla_by_id(self, issue_id_or_key, sla_id):
         """
@@ -489,7 +527,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param sla_id: str
         :return: SLA information
         """
-        url = 'rest/servicedeskapi/request/{0}/sla/{1}'.format(issue_id_or_key, sla_id)
+        url = "rest/servicedeskapi/request/{0}/sla/{1}".format(issue_id_or_key, sla_id)
 
         return self.get(url, headers=self.experimental_headers)
 
@@ -503,17 +541,17 @@ class ServiceDesk(AtlassianRestAPI):
         :param limit: OPTIONAL: int
         :return:
         """
-        url = 'rest/servicedeskapi/request/{}/approval'.format(issue_id_or_key)
+        url = "rest/servicedeskapi/request/{}/approval".format(issue_id_or_key)
         params = {}
         if start is not None:
-            params['start'] = int(start)
+            params["start"] = int(start)
         if limit is not None:
-            params['limit'] = int(limit)
+            params["limit"] = int(limit)
 
         response = self.get(url, headers=self.experimental_headers, params=params)
         if self.advanced_mode:
             return response
-        return (response or {}).get('values')
+        return (response or {}).get("values")
 
     def get_approval_by_id(self, issue_id_or_key, approval_id):
         """
@@ -523,7 +561,9 @@ class ServiceDesk(AtlassianRestAPI):
         :param approval_id: str
         :return:
         """
-        url = 'rest/servicedeskapi/request/{0}/approval/{1}'.format(issue_id_or_key, approval_id)
+        url = "rest/servicedeskapi/request/{0}/approval/{1}".format(
+            issue_id_or_key, approval_id
+        )
 
         return self.get(url, headers=self.experimental_headers)
 
@@ -536,8 +576,10 @@ class ServiceDesk(AtlassianRestAPI):
         :param decision: str
         :return:
         """
-        url = 'rest/servicedeskapi/request/{0}/approval/{1}'.format(issue_id_or_key, approval_id)
-        data = {'decision': decision}
+        url = "rest/servicedeskapi/request/{0}/approval/{1}".format(
+            issue_id_or_key, approval_id
+        )
+        data = {"decision": decision}
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -548,7 +590,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param project_key: str
         :return:
         """
-        url = 'rest/servicedeskapi/queues/{}'.format(project_key)
+        url = "rest/servicedeskapi/queues/{}".format(project_key)
 
         return self.get(url, headers=self.experimental_headers)
 
@@ -564,8 +606,8 @@ class ServiceDesk(AtlassianRestAPI):
         :param list_of_usernames: list
         :return: the customers added to the service desk
         """
-        url = 'rest/servicedeskapi/servicedesk/{}/customer'.format(service_desk_id)
-        data = {'usernames': list_of_usernames}
+        url = "rest/servicedeskapi/servicedesk/{}/customer".format(service_desk_id)
+        data = {"usernames": list_of_usernames}
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -583,15 +625,15 @@ class ServiceDesk(AtlassianRestAPI):
         :param limit: int
         :return: a page of queues
         """
-        url = 'rest/servicedeskapi/servicedesk/{}/queue'.format(service_desk_id)
+        url = "rest/servicedeskapi/servicedesk/{}/queue".format(service_desk_id)
         params = {}
 
         if include_count is not None:
-            params['includeCount'] = bool(include_count)
+            params["includeCount"] = bool(include_count)
         if start is not None:
-            params['start'] = int(start)
+            params["start"] = int(start)
         if limit is not None:
-            params['limit'] = int(limit)
+            params["limit"] = int(limit)
 
         return self.get(url, headers=self.experimental_headers, params=params)
 
@@ -611,14 +653,15 @@ class ServiceDesk(AtlassianRestAPI):
         :param limit: int
         :return: a page of issues
         """
-        url = 'rest/servicedeskapi/servicedesk/{0}/queue/{1}/issue'.format(service_desk_id,
-                                                                           queue_id)
+        url = "rest/servicedeskapi/servicedesk/{0}/queue/{1}/issue".format(
+            service_desk_id, queue_id
+        )
         params = {}
 
         if start is not None:
-            params['start'] = int(start)
+            params["start"] = int(start)
         if limit is not None:
-            params['limit'] = int(limit)
+            params["limit"] = int(limit)
 
         return self.get(url, headers=self.experimental_headers, params=params)
 
@@ -628,11 +671,12 @@ class ServiceDesk(AtlassianRestAPI):
         :param plugin_path:
         :return:
         """
-        files = {
-            'plugin': open(plugin_path, 'rb')
-        }
-        upm_token = \
-            self.request(method='GET', path='rest/plugins/1.0/', headers=self.no_check_headers, trailing=True).headers[
-                'upm-token']
-        url = 'rest/plugins/1.0/?token={upm_token}'.format(upm_token=upm_token)
+        files = {"plugin": open(plugin_path, "rb")}
+        upm_token = self.request(
+            method="GET",
+            path="rest/plugins/1.0/",
+            headers=self.no_check_headers,
+            trailing=True,
+        ).headers["upm-token"]
+        url = "rest/plugins/1.0/?token={upm_token}".format(upm_token=upm_token)
         return self.post(url, files=files, headers=self.no_check_headers)
